@@ -21,6 +21,8 @@ includes:
 
  * Reporting the position of the cursor
 
+ * Enabling or disabling automatic line wrapping
+
  * Scrolling the screen up or down
 
  * Switching between the Alternate and Normal Screen Buffers
@@ -84,9 +86,9 @@ dervied projects, and for \'WSL\' (Windows Subsystem for Linux).
 GHC's management of input and output (IO) on Windows has also developed over
 time. If they are supported by the terminal software, some control character
 sequences cause data to be emitted into the console input stream. For GHC's
-historical and default IO manager, the function 'hGetBufNonBlocking' in module
-"System.IO" does not work on Windows. This has been attributed to the lack of
-non-blocking primatives in the operating system (see
+historical and default IO manager, the function 'System.IO.hGetBufNonBlocking'
+in module "System.IO" does not work on Windows. This has been attributed to the
+lack of non-blocking primatives in the operating system (see
   [GHC bug report #806](https://ghc.haskell.org/trac/ghc/ticket/806). GHC's
 native IO manager on Windows (\'WinIO\'), introduced as a preview in
   [GHC 9.0.1](https://downloads.haskell.org/ghc/9.0.1/docs/html/users_guide/9.0.1-notes.html#highlights),
@@ -197,6 +199,7 @@ module System.Console.ANSI
   , cursorBackwardCode
 
     -- * Cursor movement by line
+    --
     -- | The difference between movements \"by character\" and \"by line\" is
     -- that @*Line@ functions additionally move the cursor to the start of the
     -- line, while functions like @cursorUp@ and @cursorDown@ keep the column
@@ -221,6 +224,7 @@ module System.Console.ANSI
   , setCursorPositionCode
 
     -- * Saving, restoring and reporting cursor position
+    --
     -- | These code sequences are not part of ECMA-48 standard; they are popular,
     -- but non-portable extensions. E. g., Terminal.app on MacOS
     -- <https://stackoverflow.com/questions/25879183 does not support them>.
@@ -243,6 +247,7 @@ module System.Console.ANSI
   , reportCursorPositionCode
 
     -- * Clearing parts of the screen
+    --
     -- | Note that these functions only clear parts of the screen. They do not
     -- move the cursor. Some functions are based on the whole screen and others
     -- are based on the line in which the cursor is located.
@@ -267,6 +272,19 @@ module System.Console.ANSI
   , clearFromCursorToLineBeginningCode
   , clearLineCode
 
+    -- * Enabling and disabling automatic line wrapping
+    --
+    -- | These functions control whether or not characters automatically wrap to
+    -- the next line when the cursor reaches the right border.
+  , enableLineWrap
+  , disableLineWrap
+    -- ** \'h...\' variants
+  , hEnableLineWrap
+  , hDisableLineWrap
+    -- ** \'...Code\' variants
+  , enableLineWrapCode
+  , disableLineWrapCode
+
     -- * Scrolling the screen
   , scrollPageUp
   , scrollPageDown
@@ -278,6 +296,7 @@ module System.Console.ANSI
   , scrollPageDownCode
 
     -- * Using screen buffers
+    --
     -- | These code sequences are not part of ECMA-48 standard; they are popular,
     -- but non-portable extensions, corresponding to @smcup@ and @rmcup@ capabilities
     -- in @terminfo@ database.
@@ -303,6 +322,7 @@ module System.Console.ANSI
   , setSGRCode
 
     -- * Cursor visibilty changes
+    --
     -- | Strictly speaking, these code sequences are not part of ECMA-48 standard;
     -- they are popular, but non-portable extensions. However, in practice they seem
     -- to work pretty much everywhere.
@@ -316,6 +336,7 @@ module System.Console.ANSI
   , showCursorCode
 
     -- * Hyperlinks
+    --
     -- | These code sequences are not part of ECMA-48 standard and not even an
     -- @xterm@ extension. Nevertheless
     -- <https://gist.github.com/egmontkob/eb114294efbcd5adb1944c9f3cb5feda many terminals>
@@ -600,7 +621,7 @@ setTitle = hSetTitle stdout
 -- will work with a given handle.
 --
 -- If the handle is not writable (that is, it cannot manage output - see
--- 'hIsWritable'), then @pure False@ is returned.
+-- 'System.IO.hIsWritable'), then @pure False@ is returned.
 --
 -- For Unix-like operating systems, the current implementation checks
 -- that: (1) the handle is a terminal; and (2) a @TERM@ environment variable is
@@ -611,12 +632,12 @@ setTitle = hSetTitle stdout
 -- a terminal, (2) a @TERM@ environment variable is not set to @dumb@, and (3)
 -- the processing of \'ANSI\' control characters in output is enabled; and
 -- second, as an alternative, whether the handle is connected to a \'mintty\'
--- terminal. (That is because the function 'hIsTerminalDevice' is used to check
--- if the handle is a terminal. However, where a non-native Windows terminal
--- (such as \'mintty\') is implemented using redirection, that function will not
--- identify a handle to the terminal as a terminal.) If it is not already
--- enabled, this function does *not* enable the processing of \'ANSI\' control
--- characters in output (see 'hNowSupportsANSI').
+-- terminal. (That is because the function 'System.IO.hIsTerminalDevice' is used
+-- to check if the handle is a terminal. However, where a non-native Windows
+-- terminal (such as \'mintty\') is implemented using redirection, that function
+-- will not identify a handle to the terminal as a terminal.) If it is not
+-- already enabled, this function does *not* enable the processing of \'ANSI\'
+-- control characters in output (see 'hNowSupportsANSI').
 --
 -- @since 0.6.2
 hSupportsANSI :: Handle -> IO Bool
@@ -955,7 +976,7 @@ getTerminalSize = hGetTerminalSize stdout
 
 -- | Attempts to get the current terminal size (height in rows, width in
 -- columns), by writing control character sequences to the specified handle
--- (which will typically be 'stdout' or 'stderr').
+-- (which will typically be 'stdout' or 'System.IO.stderr').
 --
 -- There is no \'ANSI\' control character sequence that reports the terminal
 -- size. So, it attempts to set the cursor position beyond the bottom right
@@ -1028,6 +1049,16 @@ clearFromCursorToLineEnd = hClearFromCursorToLineEnd stdout
 clearFromCursorToLineBeginning = hClearFromCursorToLineBeginning stdout
 clearLine = hClearLine stdout
 
+hEnableLineWrap, hDisableLineWrap ::
+     Handle
+  -> IO ()
+hEnableLineWrap h = hPutStr h enableLineWrapCode
+hDisableLineWrap h = hPutStr h disableLineWrapCode
+
+enableLineWrap, disableLineWrap :: IO ()
+enableLineWrap = hEnableLineWrap stdout
+disableLineWrap = hDisableLineWrap stdout
+
 hScrollPageUp, hScrollPageDown ::
      Handle
   -> Int -- Number of lines to scroll by
